# NRGTEN
Najmanovich Research Group Toolkit for Elastic Networks

If you use NRGTEN, please cite this paper: https://doi.org/10.1093/bioinformatics/btab189

The NRGTEN documentation is hosted here: https://nrgten.readthedocs.io/en/latest
